/* FlowSurgeon debug panel — self-contained styles */

#fs-root * {
  box-sizing: border-box;
  font-family: ui-monospace, "SFMono-Regular", Menlo, Consolas, monospace;
  font-size: 12px;
  line-height: 1.5;
}

#fs-root {
  position: fixed;
  bottom: 0;
  right: 0;
  z-index: 2147483647;
  width: 420px;
  max-height: 60vh;
  background: #1e1e2e;
  color: #cdd6f4;
  border-top: 2px solid #89b4fa;
  border-left: 2px solid #89b4fa;
  border-radius: 6px 0 0 0;
  box-shadow: -4px -4px 24px rgba(0, 0, 0, 0.5);
  display: flex;
  flex-direction: column;
  overflow: hidden;
}

#fs-toolbar {
  display: flex;
  align-items: center;
  background: #181825;
  padding: 6px 10px;
  gap: 8px;
  flex-shrink: 0;
  border-bottom: 1px solid #313244;
}

#fs-toolbar .fs-title {
  font-weight: 700;
  color: #89b4fa;
  letter-spacing: 0.5px;
  flex: 1;
}

#fs-toolbar .fs-badge {
  background: #313244;
  color: #cdd6f4;
  padding: 1px 6px;
  border-radius: 99px;
  font-size: 11px;
}

#fs-toolbar .fs-badge.fs-ok   { background: #a6e3a1; color: #1e1e2e; }
#fs-toolbar .fs-badge.fs-warn { background: #f9e2af; color: #1e1e2e; }
#fs-toolbar .fs-badge.fs-err  { background: #f38ba8; color: #1e1e2e; }

#fs-toolbar button {
  background: none;
  border: none;
  color: #6c7086;
  cursor: pointer;
  padding: 2px 4px;
  border-radius: 3px;
  font-size: 14px;
  line-height: 1;
}

#fs-toolbar button:hover { color: #cdd6f4; background: #313244; }

#fs-body {
  overflow-y: auto;
  padding: 10px;
  flex: 1;
}

.fs-section { margin-bottom: 12px; }

.fs-section-title {
  color: #89b4fa;
  font-weight: 700;
  text-transform: uppercase;
  letter-spacing: 0.8px;
  font-size: 10px;
  margin-bottom: 6px;
  border-bottom: 1px solid #313244;
  padding-bottom: 3px;
}

.fs-table {
  width: 100%;
  border-collapse: collapse;
}

.fs-table td {
  padding: 2px 4px;
  vertical-align: top;
}

.fs-table td:first-child {
  color: #6c7086;
  white-space: nowrap;
  padding-right: 10px;
}

.fs-table td:last-child {
  color: #cdd6f4;
  word-break: break-all;
}

.fs-link {
  color: #89b4fa;
  text-decoration: none;
  cursor: pointer;
}

.fs-link:hover { text-decoration: underline; }

/* Collapsed state */
#fs-root.fs-collapsed #fs-body { display: none; }
#fs-root.fs-collapsed { max-height: unset; border-radius: 6px 0 0 6px; }
